import {h, Component} from 'preact'
import {searchIcon} from './icons'

export class Search extends Component {
  constructor (props) {
    super(props)

    this.state = {searching: false}
  }

  onSearchClick () {
    let searching = this.state.searching

    const {value} = this.input

    if (searching && value !== '') {
      location.href = `/search?addsearch=${value}`
    } else {
      searching = !searching
      this.setState({searching}, () => {
        this.input.focus()
      })
    }

    this.props.onSearchClick(searching)
  }
  
  cancelSearch () {
    this.setState({searching: false})
    setTimeout(this.props.onSearchClick, 200, false)
  }

  render ({mobile}, {searching}) {
    return (
      <div class='fl fl-center w-full'>
        <span onClick={() => searching || mobile ? this.onSearchClick() : null}>
          <div class='h-25' style={mobile ? {} : {
            width: searching ? '' : '0px',
            opacity: searching ? '1' : '0',
            transform: 'scale(0.8)',
            zIndex: searching ? '1' : '0'
          }}>
            {searchIcon}
          </div>
        </span>
        
        {mobile !== true &&
        <p class='m-r-10' onClick={() => searching || mobile ? null : this.onSearchClick()} style={{
          cursor: 'pointer',
          color: '#798186',
          fontSize: '14px',
          width: searching ? '0px' : '',
          opacity: searching ? '0' : '1',
          zIndex: searching ? '1' : '0'
        }}>Search</p>}

        <input
          class='p-v-5'
          ref={(el) => { this.input = el }}
          onKeyDown={(e) => { if (e.keyCode === 13) this.onSearchClick() }}
          onBlur={() => { this.cancelSearch() }}
          style={{
            display: 'inline',
            border: '0',
            outline: '0',
            borderBottom: '1px solid',
            fontSize: '16px',
            margin: searching ? '0px 30px 0 15px' : '0 10px',
            transition: '500ms cubic-bezier(0.230, 1.000, 0.320, 1.000)',
            width: searching ? `${mobile ? (window.innerWidth - 150) : 300}px` : '0px'
          }} />
      </div>
    )
  }
}
